@@ -1,13 +1,13 @@
-from typing import Any, List, Dict, Sequence, Set, Union
-from dagster.core.definitions.events import Output
-from qdk.materialization import Materializer
+from typing import Any, Dict, List, Sequence, Set
+
 from dagster import (
+    Field,
     InputDefinition,
     OutputDefinition,
     SolidDefinition,
     SolidExecutionContext,
-    Field,
 )
+from dagster.core.definitions.events import Output
 
 
 class BaseComponent:
