@@ -1,4 +1,4 @@
-from typing import Dict, List, Union
+from typing import List, Set, Union
 
 import dask.dataframe as dd
 import nltk
@@ -12,12 +12,12 @@ class NounPhraseComponent(TransformComponent):
     replace_pos = {
         "ADJ": "JJ",
         "NOUN": "NN",
-        "PROPN": "NN",
+        # "PROPN": "NN",
     }
     noun_phrase_regex = "NP: {<NN.*|JJ>*<NN.*>}"
 
     @classmethod
-    def extract_noun_phrases(cls, text: str, nlp: spacy.Language) -> Dict[str]:
+    def extract_noun_phrases(cls, text: str, nlp: spacy.Language) -> Set[str]:
         """This function takes a string as input and outputs a list of
         noun phrase candidates:
 
@@ -28,7 +28,7 @@ class NounPhraseComponent(TransformComponent):
             nlp (spacy.Language): A spacy language model. Used for POS tagging.
 
         Returns:
-            Dict[str]: The noun phrases found in the text.
+            Set[str]: The noun phrases found in the text.
         """
         # Clean the text before extracting phrases
         cleaned_text = clean_text(text=text)
